aboutsummaryrefslogtreecommitdiff
path: root/include/llvm/ADT/Triple.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/ADT/Triple.h')
-rw-r--r--include/llvm/ADT/Triple.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/llvm/ADT/Triple.h b/include/llvm/ADT/Triple.h
index f317c190b0..49d9f68404 100644
--- a/include/llvm/ADT/Triple.h
+++ b/include/llvm/ADT/Triple.h
@@ -100,8 +100,8 @@ public:
Haiku,
Minix,
RTEMS,
- NativeClient,
- CNK, // BG/P Compute-Node Kernel
+ NaCl, // Native Client
+ CNK, // BG/P Compute-Node Kernel
Bitrig,
AIX
};
@@ -310,9 +310,9 @@ public:
return getOS() == Triple::Win32 || isOSCygMing();
}
/// \brief isOSNaCl - Is this the Native Client OS.
bool isOSNaCl() const {
- return getOS() == Triple::NativeClient;
+ return getOS() == Triple::NaCl;
}
/// \brief Tests whether the OS uses the ELF binary format.
@@ -310,9 +310,9 @@ public:
return getOS() == Triple::Win32 || isOSCygMing();
}
- /// \brief isOSNaCl - Is this the Native Client OS.
+ /// \brief Tests whether the OS is NaCl (Native Client)
bool isOSNaCl() const {